summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authordanieldg <danieldg@e03df62e-2008-0410-955e-edbf42e46eb7>2009-09-18 17:07:13 +0000
committerdanieldg <danieldg@e03df62e-2008-0410-955e-edbf42e46eb7>2009-09-18 17:07:13 +0000
commita068c47d71e9a922b145b7552b3a64d638c92171 (patch)
treeb78e21ea491683cd2238c49f02aced889f488260 /include
parent792d6d6725c7d80d223f5cccd9ee0c5b07229e9a (diff)
Separate spy channels [jackmcbarn]
git-svn-id: http://svn.inspircd.org/repository/trunk/inspircd@11747 e03df62e-2008-0410-955e-edbf42e46eb7
Diffstat (limited to 'include')
-rw-r--r--include/users.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/include/users.h b/include/users.h
index 505c43b9e..f9be74924 100644
--- a/include/users.h
+++ b/include/users.h
@@ -865,12 +865,12 @@ class CoreExport User : public EventHandler
*/
void SendAll(const char* command, const char* text, ...) CUSTOM_PRINTF(3, 4);
/** Compile a channel list for this user, and send it to the user 'source'
* Used internally by WHOIS
* @param The user to send the channel list to if it is not too long
* @return This user's channel list
*/
- std::string ChannelList(User* source);
+ std::string ChannelList(User* source, bool spy);
/** Split the channel list in cl which came from dest, and spool it to this user
* Used internally by WHOIS
@@ -865,12 +865,12 @@ class CoreExport User : public EventHandler
*/
void SendAll(const char* command, const char* text, ...) CUSTOM_PRINTF(3, 4);
- /** Compile a channel list for this user, and send it to the user 'source'
- * Used internally by WHOIS
- * @param The user to send the channel list to if it is not too long
+ /** Compile a channel list for this user. Used internally by WHOIS
+ * @param source The user to prepare the channel list for
+ * @param spy Whether to return the spy channel list rather than the normal one
* @return This user's channel list
*/